define(["global", "Backbone"], function() {
	return Backbone.View.extend({
		el : "#discover",
		title : {
			left : {
				show : false
			}, 
			center : {
				text : "发现"
			},
			right : {
				show : true,
				text : "全部",
				url : "fund-list.html"
			}, 
		},
		events : {},
		initialize : function() {
			this.requestManager = $.hsf.requestManager(this);
			this.requestManager.add(this.getDiscoverList, 60*60*1);
		},
		render :function() {
		},
		constant : {
			moneyFundTag : {},
			recommendList : {},
			subjectList : {},
			ztDict : {
				"dayinc":{key:"increase", value:"日涨跌"},
				"seasonhinc":{key:"mreturnrate3", value:"近3月收益"},
				"halfinc":{key:"mreturnrate6", value:"近6月收益"},
				"yearinc":{key:"yreturnrate1", value:"近1年收益"},
				"threeyearinc":{key:"yreturnrate3",value:"近3年收益"},
				"thisyearinc":{key:"yreturnrate", value:"今年以来收益"},
				"setupinc":{key:"returnrate", value:"成立以来收益"},
				"default" :{key:"mreturnrate3", value:"近3月收益"},
			}
		},
		process : function() {
			this.getDiscoverList();
		},
		getDiscoverList : function() {
			$.hsf.startLoading();
			var that = this;
			return $.hsf.ajax.app("product/product/findPage", "", "discoverListCallback", function(jsonResult) {
				$.hsf.stopLoading();
				var decimal2 = $.hsf.hsTools.decimal2;
				function render(jsonResult) {
					if (jsonResult.recommendList) {
                    	jsonResult.recommendList.sort(function(a, b) {
							if(a.status != b.status){
								return a.status < b.status ? 1 : -1;
							}else{
								if (a.risklevel == b.risklevel) {
									return a.yreturnrate1 < b.yreturnrate1 ? 1 : -1;
								} else {
									return a.risklevel < b.risklevel ? 1 : -1;
								}
							}
						})
						for ( var j = 0; j < jsonResult.recommendList.length; j++) {
							var recd = jsonResult.recommendList[j];
							if (recd.risklevel == "01") {
								recd.risklevelStyle = 'e-blue-list';
							} else if (recd.risklevel == "02" || recd.risklevel == "03") {
								recd.risklevelStyle = 'e-yellow-list';
							} else if (recd.risklevel == "04" || recd.risklevel == "05") {
								recd.risklevelStyle = 'e-orange-list';
							}

							var rateGD = that.constant.ztDict[recd.incInterval];
							if (rateGD) {
								recd.rate = rateGD;
							} else {
								recd.rate = that.constant.ztDict["default"];
							}
							if (recd[recd.rate.key]) {
								recd[recd.rate.key] = decimal2(recd[recd.rate.key]);
								if (parseFloat(recd[recd.rate.key])>0) {
									recd.color = "fund-up"
								} else {
									recd.color = "fund-down";
								}
							} else {
								recd[recd.rate.key] = "--";
							}
							if (!recd.tags) {
								recd.tags = [];
							}
							if(recd.detailurl){
								var search = recd.detailurl.split("?")[1];
								if(search){
									var url = that.urlSplit(search);
									var data = "&fundcode="+url.fundcode + "&goflag=" + url.goflag + "&btnName=" + (url.btnName||"按钮");
									if (recd.detailurl.startsWith("local://")) {
										recd.htmlUrl = recd.detailurl.substr(8);
									} else if (recd.detailurl.startsWith("http://")) {
										recd.htmlUrl = "wpage.html?title="+url.tjTitle + data+"&src="+encodeURIComponent(recd.detailurl);
									} else if (recd.detailurl.startsWith("https://")) {
										recd.htmlUrl = "wpage.html?title="+url.tjTitle + data+"&src="+encodeURIComponent(recd.detailurl);
									}
								}else{
									if (recd.detailurl.startsWith("local://")) {
										recd.htmlUrl = recd.detailurl.substr(8);
									} else if (recd.detailurl.startsWith("http://")) {
										recd.htmlUrl = "wpage.html?title="+recd.fundname+"&src="+encodeURIComponent(recd.detailurl);
									} else if (recd.detailurl.startsWith("https://")) {
										recd.htmlUrl = "wpage.html?title="+recd.fundname+"&src="+encodeURIComponent(recd.detailurl);
									}
								}
							}else{
								if($.trim(recd.status)=="1"){
									recd.htmlUrl = "trade-buy.html?fundcode="+recd.fundcode+"&fundname="+recd.fundname;
								}else{
									recd.htmlUrl = "fund-detail.html?fundcode="+recd.fundcode;
								}
							}
						}
                    }
                    $.doTemplate("recommendTemplate", jsonResult, "refresh");
					$.doTemplate("subjectTemplate", jsonResult, "refresh");
				}
				if (jsonResult.successful) {
					$.hsf.stopLoading();
                    render.call(that, jsonResult);
					$.platform.putCache("discover", jsonResult);
				} else {
					if (jsonResult.code == "NETWORK_ERROR") {
						$.platform.getCache("discover", function(jsonResult) {
							if (jsonResult) {
								render.call(that, jsonResult);	
							}
						});
					}
					that.requestManager.resetTime(that.getDiscoverList);
					$.hsf.callFailProcess(jsonResult);
				}
			});
		},
		urlSplit : function(url){
			var queryObject = {};
			var pairs = url.split('&');
			for(var i in pairs) {
				var pair = pairs[i];
				var keyAndValue = pair.split('=');
				var key = keyAndValue[0];
				var value = keyAndValue[1];
				queryObject[key] = value;
			}
			return queryObject;
		},
		afterSwitchView : function() {
			this.requestManager.invoke(this.getDiscoverList);
		}
	});
})
