define(['swiper'], function() {
	var constant = {
		toolbarFocus: "increase"
	};
	var main = {};
	main.init = function() {
		$.platform.getCache("openId", function(openId) {
			constant.openId = openId||"";
			packForm();
		});
		$.platform.initPage();
	};
	return main;

	function packForm() {
		$.hsf.startLoading();
		$.hsf.ajax.app("product/product/fundinfo", "openId="+constant.openId, "productListback", function(jsonResult) {
			if (jsonResult.successful) {
				loadFundList(jsonResult);
				$.hsf.stopLoading();
			}
		});
	}

	function loadFundList(jsonResult) {
		var fundPages = initFundGroup(jsonResult);
		renderNav(fundPages);
		renderContent(fundPages);
		setContentSize();
		initSwiperList();
		searchBar();
		events();
		$.hsf.stopLoading();

		function initFundGroup(jsonResult) {
			var fundGroup = [],
				productList = jsonResult.result.data,
				fundDict = $.hsf.fundtypeDict,
				followFund = jsonResult.result.myFollows,
				fundTag = jsonResult.result.tags;
			var fundDictMap = getDictMap(fundDict);
			for (var index in productList) { //分组
				var fund = productList[index];
				if (fund.status == "1" || fund.fundtype =="4"||fund.suppermoneyfund) continue;
				fund.index = index;
				fund.fundtypestr = fundDictMap[fund.fundtype];
				formatFundData(fund, followFund, fundTag);
				if (!fundGroup[fund.fundtype]) {
					fundGroup[fund.fundtype] = [];
				}
				fundGroup[fund.fundtype].push(fund);
			}
			var filtedFundDict = [];
			for (var index in fundDict) {
				if (fundGroup[fundDict[index].key]) { //过滤空的fundDict
					fundDict[index].fundGroup = fundGroup[fundDict[index].key];
					filtedFundDict.push(fundDict[index]);
				}
			}
			initSort(fundGroup);
			constant.moneyFundIndex = findMoneyFundIndex(filtedFundDict);
			return filtedFundDict;
		}

		function getDictMap(fundDict) {
			var fundDictMap = {};
			for (var index in fundDict) {
				if (fundDict[index].value.indexOf('型')<=0) {
					fundDict[index].value = fundDict[index].value+"型";
				}
				fundDictMap[fundDict[index].key] = fundDict[index].value;
			}
			return fundDictMap;
		}

		function formatFundData(fund, followFund, fundTag) {
			var findFundTags = function(fundcode) {
				for (var index in fundTag) {
					if (fundcode == fundTag[index].key) {
						return fundTag[index].value;
					}
				};
			};
			var findFollowFund = function(fundcode) {
				for (var index in followFund) {
					if (fundcode == followFund[index]) {
						return true;
					}
				}
				return false;
			};
			var addPercentSymbol = function(value) {
				if (value != '--') {
					value += "%";
				}
				return value;
			}
			var tool = $.hsf.hsTools;
			fund.fundnameLength = Math.ceil(fund.fundname.replace(/[^\x00-\xff]/g, '12').length / 2);
			fund.increase = addPercentSymbol(tool.decimal2(fund.increase));
			fund.mreturnrate3 = addPercentSymbol(tool.decimal2(fund.mreturnrate3));
			fund.mreturnrate6 = addPercentSymbol(tool.decimal2(fund.mreturnrate6));
			fund.yreturnrate1 = addPercentSymbol(tool.decimal2(fund.yreturnrate1));
			fund.yreturnrate = addPercentSymbol(tool.decimal2(fund.yreturnrate));
			fund.incomdepercent = addPercentSymbol(tool.decimal4(fund.incomdepercent));
			fund.isFollow = findFollowFund(fund.fundcode);
			fund.fundTags = findFundTags(fund.fundcode);
			fund.navdate = tool.yyyy_mm_dd(fund.navdate);
			fund.nav = tool.defaultNull(fund.nav, "--");
		}
		
		function initNull(value, info) {
			if (value == "--") {
				if(info == "down"){
					return 10000000;
				}else if(info == "up"){
					return -10000000;
				}else{
					return -10000000;
				}
			} else {
				return value;
			}
		};

		function initSort(fundGroup) {
			
			for (var index in fundGroup) { //排序
				if (index == 2) { //货基
					fundGroup[index].sort(function(a, b) {
						var a = initNull(a.incomdepercent);
						var b = initNull(b.incomdepercent);
						return parseFloat(a) < parseFloat(b) ? 1 : -1;
					});
				} else {
					fundGroup[index].sort(function(a, b) {
						var a = initNull(a.increase);
						var b = initNull(b.increase);
						return parseFloat(a) < parseFloat(b) ? 1 : -1;
					});
				}
			}
			return fundGroup;
		}

		function findMoneyFundIndex(fundDict) {
			for (var index in $.hsf.fundtypeDict) { //写头
				if ($.hsf.fundtypeDict[index].key == "2") {
					return index;
				}
			}
			return null;
		}

		function renderNav(fundDict) {
			$.doTemplate('navArea', fundDict);
		}

		function renderContent(fundDict) {
			$.doTemplate('contentHeaderArea', fundDict);
			$.doTemplate('contentArea', fundDict);
			$("[m-role='UITableView']").UITableView("refresh");
		}

		function initSwiperList() {
            var way = 0;
            var k =1;
			var changeTitle = function(swiper) {
                if(way == 1)
                    k = swiper.clickedIndex;
                else
                    k = swiper.activeIndex;
				if (k == constant.moneyFundIndex) {
					$("#title2").html("万分收益");
					$("#title3").html("七日年化");
				} else {
					$("#title2").html("净值");
					$("#title3").html($(".toolbar-item.on").html() + "涨幅");
				}
			};
			var navSwiper = new Swiper('.nav-swiper', {
				freeMode: true,
				freeModeMomentum: false,
				slidesPerView: "auto",
				resistanceRatio: 0,
				onTap: function(swiper) {
                    way = 1;
					changeTitle(swiper);
					contentSwiper.slideTo(swiper.clickedIndex);
					return false;
				}
			});
			var contentSwiper = new Swiper('.swiper-content', {
				slidesPerView: 1,
				resistanceRatio: 0.5,
				touchMoveStopPropagation: true,
				onSlideChangeStart: function(swiper) {
					$('.nav-swiper .swiper-slide').removeClass('current');
					$('.nav-swiper .swiper-slide:eq(' + swiper.activeIndex + ')').addClass('current');
                    way = 2;
					changeTitle(swiper);
				},
				onTouchEnd: function() {
					$("dd.UISelectionStyle").removeClass("UISelectionStyle");
				}
			});
			contentSwiper.params.control = navSwiper;
		}

		function searchBar() {
			$(".searchbar").UISearchBar("dataList", ".dlist");
		}

		function setContentSize() {
			$('.swiper-content').css({
				"height": $(window).height() - $("[m-role='UINavigationBar']").outerHeight() - $(".nav-swiper").outerHeight() - $(".fund-list-header").outerHeight() - $(".toolbar").outerHeight()
			});
		}

		function events() {
			$(window).resize(function() {
				setContentSize();
			});
			$("#t3").bind("tap", function() {
				var $order = $(this).find(".order");
				var id = $(".toolbar-item.on").attr("id");
				var sortData = function(direct) {
					console.log(id);
					$.each($(".swiper-content > .swiper-wrapper > .swiper-slide"), function(i, n) {
						var $dl = $(n).find("dl");
						var ddlist = $dl.find("dd");
						var truefund = [];
						var falsefund = [];
						$.each(ddlist, function(info){
							var value = $(ddlist[info]).find(".right_top").html();
							if(value == "--"){
								falsefund.push(ddlist[info]);
							}else{
								truefund.push(ddlist[info]);
							}
						});
						var $dd = $dl.find("dd").get().reverse();
						$dl.empty().append($dd);
						$dl.append(falsefund);
					});
					$("[m-role='UITableView']").UITableView("refresh");
				};
				if ($order.hasClass("order-down")) {
					sortData("up");
					$order.removeClass("order-down").addClass("order-up");
				} else {
					sortData("down");
					$order.removeClass("order-up").addClass("order-down");
                };
				return false;
			});

			$("#searchBtn").bind("tap", function() {
				$("#first").hide();
				$("#searchPage").show();
				$("[m-role='UISearchBar']").UISearchBar();
			});

			$(".swiper-content > .swiper-wrapper").on("tap", ".fund-fav", function() {
				var _self = $(this);
				var fav = _self.find(".fund-fav-item2");
				var fundcode = $(_self).parent().parent().find(".fundcode").html();
				var status = fav.hasClass("on");
				var requestStatus = !status;
				var data = "fundcode=" + fundcode + "&status=" + requestStatus+"&openId="+constant.openId;
				$.hsf.ajax.app("weixin/wxzt/changeFollow", data, "addFavoriteCallback", function(jsonResult) {
					if (jsonResult.successful) {
						if(status == true)
                            fav.removeClass("on");
                        else
                            fav.addClass("on");
					} else {
						$.hsf.callFailProcess(jsonResult);
					};
				});
				return false;
			});

			$(".toolbar-item").on('click', function() {
				var _self = $(this);
				var changeInc = function(id) {
					//var id = _self.attr("id");
					if(id == "increase"){//日涨幅
						$(".swiper-content > .swiper-wrapper > .swiper-slide").find("[fundtype!='2']");
						$.each($(".swiper-content > .swiper-wrapper > .swiper-slide"), function(i, slide) {
							var $slide = $(slide);
							if ($slide.attr("fundtype") != "2") {
								var dds = $slide.find("dd");
								$.each($slide.find(".right_top"), function(i, inc) {
									var $inc = $(inc);
									var value = $inc.attr(id);
									$inc.html(value);
									$inc.parents("dd").attr("inc", value);
									$inc.removeClass("fund-up fund-down").addClass(parseFloat(value) >= 0 ? "fund-up" : "fund-down");
								});
								var title3Direct = $("#t3 > .order-down").length == 1 ? "up" : "down";
								var dds = $slide.find("dd");
								dds.sort(function(aNum, bNum) {
									var a = initNull(aNum.getAttribute("inc"));
									var b = initNull(bNum.getAttribute("inc"));
									if (title3Direct == "down") {
										return parseFloat(a) > parseFloat(b) ? 1 : -1;
									} else {
										return parseFloat(a) < parseFloat(b) ? 1 : -1;
									}
								});
								var $dl = $slide.find("dl")
								$dl.empty().append(dds);
							}
						});
					}else if(id == "mreturnrate3"){//季涨幅
						$(".swiper-content > .swiper-wrapper > .swiper-slide").find("[fundtype!='2']");
						$.each($(".swiper-content > .swiper-wrapper > .swiper-slide"), function(i, slide) {
							var $slide = $(slide);
							if ($slide.attr("fundtype") != "2") {
								var dds = $slide.find("dd");
								$.each($slide.find(".right_top"), function(i, inc) {
									var $inc = $(inc);
									var value = $inc.attr(id);
									$inc.html(value);
									$inc.parents("dd").attr("mreturnrate3", value);
									$inc.removeClass("fund-up fund-down").addClass(parseFloat(value) >= 0 ? "fund-up" : "fund-down");
								});
								var title3Direct = $("#t3 > .order-down").length == 1 ? "up" : "down";
								var dds = $slide.find("dd");
								dds.sort(function(aNum, bNum) {
									var a = initNull(aNum.getAttribute("mreturnrate3"));
									var b = initNull(bNum.getAttribute("mreturnrate3"))
									if (title3Direct == "down") {
										return parseFloat(a) > parseFloat(b) ? 1 : -1;
									} else {
										return parseFloat(a) < parseFloat(b) ? 1 : -1;
									}
								});
								var $dl = $slide.find("dl")
								$dl.empty().append(dds);
							}
						});
					}else if(id == "mreturnrate6"){// 半年涨幅
						$(".swiper-content > .swiper-wrapper > .swiper-slide").find("[fundtype!='2']");
						$.each($(".swiper-content > .swiper-wrapper > .swiper-slide"), function(i, slide) {
							var $slide = $(slide);
							if ($slide.attr("fundtype") != "2") {
								var dds = $slide.find("dd");
								$.each($slide.find(".right_top"), function(i, inc) {
									var $inc = $(inc);
									var value = $inc.attr(id);
									$inc.html(value);
									$inc.parents("dd").attr("mreturnrate6", value);
									$inc.removeClass("fund-up fund-down").addClass(parseFloat(value) >= 0 ? "fund-up" : "fund-down");
								});
								var title3Direct = $("#t3 > .order-down").length == 1 ? "up" : "down";
								var dds = $slide.find("dd");
								dds.sort(function(aNum, bNum) {
									var a = initNull(aNum.getAttribute("mreturnrate6"));
									var b = initNull(bNum.getAttribute("mreturnrate6"))
									if (title3Direct == "down") {
										return parseFloat(a) > parseFloat(b) ? 1 : -1;
									} else {
										return parseFloat(a) < parseFloat(b) ? 1 : -1;
									}
								});
								var $dl = $slide.find("dl")
								$dl.empty().append(dds);
							}
						});
					}else if("yreturnrate1"){// 年涨幅
						$(".swiper-content > .swiper-wrapper > .swiper-slide").find("[fundtype!='2']");
						$.each($(".swiper-content > .swiper-wrapper > .swiper-slide"), function(i, slide) {
							var $slide = $(slide);
							if ($slide.attr("fundtype") != "2") {
								var dds = $slide.find("dd");
								$.each($slide.find(".right_top"), function(i, inc) {
									var $inc = $(inc);
									var value = $inc.attr(id);
									$inc.html(value);
									$inc.parents("dd").attr("yreturnrate1", value);
									$inc.removeClass("fund-up fund-down").addClass(parseFloat(value) >= 0 ? "fund-up" : "fund-down");
								});
								var title3Direct = $("#t3 > .order-down").length == 1 ? "up" : "down";
								var dds = $slide.find("dd");
								dds.sort(function(aNum, bNum) {
									var a = initNull(aNum.getAttribute("yreturnrate1"), title3Direct);
									var b = initNull(bNum.getAttribute("yreturnrate1"), title3Direct);
									if (title3Direct == "down") {
										return parseFloat(a) > parseFloat(b) ? 1 : -1;
									} else {
										return parseFloat(a) < parseFloat(b) ? 1 : -1;
									}
								});
								var $dl = $slide.find("dl")
								$dl.empty().append(dds);
							}
						});
					}else if(id == "yreturnrate"){//今年涨幅
						$(".swiper-content > .swiper-wrapper > .swiper-slide").find("[fundtype!='2']");
						$.each($(".swiper-content > .swiper-wrapper > .swiper-slide"), function(i, slide) {
							var $slide = $(slide);
							if ($slide.attr("fundtype") != "2") {
								var dds = $slide.find("dd");
								$.each($slide.find(".right_top"), function(i, inc) {
									var $inc = $(inc);
									var value = $inc.attr(id);
									$inc.html(value);
									$inc.parents("dd").attr("yreturnrate", value);
									$inc.removeClass("fund-up fund-down").addClass(parseFloat(value) >= 0 ? "fund-up" : "fund-down");
								});
								var title3Direct = $("#t3 > .order-down").length == 1 ? "up" : "down";
								var dds = $slide.find("dd");
								dds.sort(function(aNum, bNum) {
									var a = initNull(aNum.getAttribute("yreturnrate"), title3Direct);
									var b = initNull(bNum.getAttribute("yreturnrate"), title3Direct);
									if (title3Direct == "down") {
										return parseFloat(a) > parseFloat(b) ? 1 : -1;
									} else {
										return parseFloat(a) < parseFloat(b) ? 1 : -1;
									}
								});
								var $dl = $slide.find("dl")
								$dl.empty().append(dds);
							}
						});
					}
					/*$.each($(".swiper-content > .swiper-wrapper > .swiper-slide"), function(i, slide) {
						var $slide = $(slide);
						if ($slide.attr("fundtype") != "2") {
							var dds = $slide.find("dd");
							$.each($slide.find(".right_top"), function(i, inc) {
								var $inc = $(inc);
								var value = $inc.attr(id);
								$inc.html(value);
								$inc.parents("dd").attr("inc", value);
								$inc.removeClass("fund-up fund-down").addClass(parseFloat(value) >= 0 ? "fund-up" : "fund-down");
							});
							var title3Direct = $("#t3 > .order-down").length == 1 ? "up" : "down";
							var dds = $slide.find("dd");
							dds.sort(function(aNum, bNum) {
								var a = initNull(aNum.getAttribute("inc"));
								var b = initNull(bNum.getAttribute("inc"))
								if (title3Direct == "down") {
									return parseFloat(a) > parseFloat(b) ? 1 : -1;
								} else {
									return parseFloat(a) < parseFloat(b) ? 1 : -1;
								}
							});
							var $dl = $slide.find("dl")
							$dl.empty().append(dds);
						}
					});*/
				}
				if (constant.toolbarFocus != _self.attr("id")) {
					_self.addClass('on').siblings().removeClass('on');
					if ($("#title3").html() != "七日年化") {
						$("#title3").html(_self.html() + "涨幅");
					}
					changeInc(_self.attr("id"));
					constant.toolbarFocus = _self.attr("id");
				}
			});

			$("#startSearch").bind("tap", function() {
				var searchBar = $(".searchbar"),
					searchContent = $('.swiper-content');
				searchBar.toggle();
				$(".search-btn").toggle();
				$("[m-role='UIBottomBar']").toggle();
			});
			$("#endSearch").bind("tap", function() {
				var searchBar = $(".searchbar"),
					searchContent = $('.swiper-content'),
					searchBarResult = $('.UISearchBarResult');
				searchBar.toggle();
				searchBarResult.hide();
				$(".searchbar").UISearchBar("cancelSearch");
				$(".search-btn").toggle();
				$("[m-role='UIBottomBar']").toggle();
			});
			$(".swiper-content dd[m-href]").unbind("tap.mhref");
		}
	}
});